# coding=utf-8
"""
Setup for scikit-surgerybard
"""

from setuptools import setup, find_packages
import versioneer

# Get the long description
with open('README.rst') as f:
    long_description = f.read()

setup(
    name='scikit-surgerybard',
    version=versioneer.get_version(),
    cmdclass=versioneer.get_cmdclass(),
    description='scikit-surgerybard is a Basic Augmented Reality Demo (BARD)'
                'based on scikit-surgery (SNAPPY)',
    long_description=long_description,
    long_description_content_type='text/x-rst',
    url='https://github.com/SciKit-Surgery/'
        'scikit-surgerybard',
    author='Stephen Thompson',
    author_email='s.thompson@ucl.ac.uk',
    license='BSD-3 license',
    classifiers=[
        'Development Status :: 3 - Alpha',

        'Intended Audience :: Developers',
        'Intended Audience :: Healthcare Industry',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Science/Research',


        'License :: OSI Approved :: BSD License',


        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',

        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Scientific/Engineering :: Medical Science Apps.',
    ],

    keywords='medical imaging',

    packages=find_packages(
        exclude=[
            'doc',
            'tests',
            'data',
        ]
    ),

    install_requires=[
        'numpy',
        'glob2',
        'PySide2<5.15.0',
        'opencv-contrib-python-headless',
        'scikit-surgerycore>=0.6.8',
        'scikit-surgerycalibration>=0.1.9',
        'scikit-surgeryutils<1.2',
        'scikit-surgeryvtk',
        'scikit-surgeryarucotracker>=0.2.5',
    ],

    entry_points={
        'console_scripts': [
            'bardVideoCalibration=sksurgerycalibration.ui.video_calibration_command_line:main',
            'bardVideoCalibrationChecker=sksurgerybard.ui.bard_video_calibration_checker_command_line:main',
            'bardPivotCalibration=sksurgerycalibration.ui.pivot_calibration_command_line:main',
            'bardProcrustes=sksurgerybard.ui.bard_procrustes_command_line:main',
            'sksurgerybard=sksurgerybard.ui.sksurgerybard_command_line:main',
        ],
    },
)
